@@ -30,7 +30,11 @@
 
 #include "AT_RDD.h"
 #include "AT_GammaResponse.h"
+#include "config.h"
 
+#ifdef HAVE_OPENMP
+#include <omp.h>
+#endif
 
 /**
  * TODO
